@@ -3,7 +3,7 @@ package Email::Outlook::Message::Base;
 
 Email::Outlook::Message::Base - Base parser for .msg files.
 
-=head1 NAME
+=head1 DESCRIPTION
 
 This is an internal module of Email::Outlook::Message.
 
@@ -29,7 +29,7 @@ Matijs van Zuijlen, C<matijs@matijs.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2002, 2004, 2006--2010, 2012 by Matijs van Zuijlen
+Copyright 2002--2020 by Matijs van Zuijlen
 
 This module is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -43,7 +43,7 @@ use POSIX;
 use Carp;
 use OLE::Storage_Lite;
 use vars qw($VERSION);
-$VERSION = "0.914";
+$VERSION = "0.920";
 
 my $DIR_TYPE = 1;
 my $FILE_TYPE = 2;
@@ -170,7 +170,6 @@ our $skipproperties = {
   '3A00' => "Account",
   '3A20' => "Transmittable Display Name",
   '3A40' => "Send Rich Info",
-  '3FDE' => "Internet Code Page", # TODO: Perhaps use this.
   # 'Display table properties'
   '3FF8' => "Creator Name",
   '3FF9' => "Creator EntryId",
@@ -247,7 +246,6 @@ sub _decode_mapi_property {
       $data = decode("UTF-16LE", $data);
     }
     $data =~ s/ \000 $ //sgx;
-    $data =~ s/ \r \n /\n/sgx;
     return $data;
   }
 
@@ -303,9 +301,6 @@ sub _parse_item_name {
 
   if ($name =~ / ^ __substg1 [ ] 0_ (....) (....) $ /x) {
     my ($property, $encoding) = ($1, $2);
-    if ($encoding eq $ENCODING_UNICODE and not ($self->{HAS_UNICODE})) {
-      $self->{HAS_UNICODE} = 1;
-    }
     return ($property, $encoding);
   } else {
     return (undef, undef);
